from __future__ import annotations

from pydantic import BaseModel


class DateObserved(BaseModel):
    type: str
    value: str


class Payload(BaseModel):
    name: str
    surname: str
    sex: str
    dob: str
    age: int
    nationality: str
    job: str
    injury: str
    transport: int
    destination: str
    service: str
    vector: str
    color: str
    identifier: str
    device: str
    incident: str
    latitude: int
    longitude: int


class Model(BaseModel):
    id: str
    type: str
    dateObserved: DateObserved
    payload: Payload



from __future__ import annotations

from typing import List

from pydantic import BaseModel
from datetime import datetime


class DateObserved(BaseModel):
    type: str
    value: datetime


class Action(BaseModel):
    timestamp: datetime
    action: str


class Payload(BaseModel):
    incident_id: str
    user_id: str
    actions: List[Action]


class Model(BaseModel):
    id: str
    type: str
    dateObserved: DateObserved
    payload: Payload



from __future__ import annotations

from pydantic import BaseModel

from datetime import datetime


class DateObserved(BaseModel):
    type: str
    value: datetime


class Payload(BaseModel):
    victim_id: str
    vitals_sensor_id: str
    vitals_sensor_type: str
    respiratory_rate: int
    systolic_blood_pressure: int
    diastolic_blood_pressure: int
    skin_temperature: float
    body_temperature: float
    heart_rate: int
    heart_rate_variability: int
    oxygen_saturation: int
    timestamp: datetime


class Model(BaseModel):
    id: str
    type: str
    dateObserved: DateObserved
    payload: Payload



import os

class UUIDGenerator(object):
    def __init__(self):
        pass
        
    def generate_uuid(self):
        randombytes = os.urandom(16)
        return randombytes.hex()
        
    def generate_uuid_pretty(self):
        uuid = self.generate_uuid()
        pretty_uuid = uuid[:8] + "-" + uuid[8:12] + "-" + uuid[12:16] + "-" + uuid[16:20] + "-" + uuid[20:]
        # self.set_last_generated_uuid(uuid)
        return pretty_uuid
        
    if __name__ == '__main__':
        generate_uuid_pretty()


from setuptools import setup, find_packages

VERSION = '2.1.0' 
DESCRIPTION = 'JSON adapter'
LONG_DESCRIPTION = 'JSON adapters and validators for Nightingale Communication and Integration'

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="nightingalejsonadapter", 
        version=VERSION,
        author="Nuno Antunes",
        author_email="<nuno.f.antunes@inov.pt>",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=['pydantic'], # add any additional packages that 
        # needs to be installed along with your package. Eg: 'caer'
        
        keywords=['jsonadapter']
)

# python setup.py sdist bdist_wheel
# twine upload dist/*


from __future__ import annotations

from typing import Any, Dict, List, Optional

from pydantic import BaseModel
from datetime import datetime
from uuid_generator import UUIDGenerator


class VitalPredictions(BaseModel):
    HR: float
    RR: float
    SBP: float
    DBP: float
    SPO2: float


class VitalEarlyWarningScore(BaseModel):
    HR: int
    RR: int
    SBP: int
    DBP: int
    SPO2: int


class ShockIndex(BaseModel):
    Value: float
    EarlyWarningScore: int


class ProcedureMessage(BaseModel):
    PredictedInterventionTimestamp: Optional[datetime.datetime] = None
    Message: Optional[str] = None


class ProcedureMessagesABC(BaseModel):
    a: ProcedureMessage
    b: ProcedureMessage
    c: ProcedureMessage


class Prediction(BaseModel):
    Timestamp: datetime
    VitalPredictions: VitalPredictions
    VitalEarlyWarningScore: VitalEarlyWarningScore
    ShockIndex: ShockIndex
    ProcedureMessagesABC: ProcedureMessagesABC


class Model(BaseModel):
    UUID: str
    LastMeasurementTimestamp: datetime
    PredictionTimestampId: str
    PredictionTimeDeltaMinutes: int
    PatientId: str
    ProcedureMessageCount: int
    Predictions: List[Prediction]